/*
 * Copyright (c) 2016 Intel Corporation
 *
 * SPDX-License-Identifier: Apache-2.0
 */
#include <zephyr/kernel.h>
#include <zephyr/device.h>
#include <zephyr/devicetree.h>
#include <zephyr/drivers/i2c.h>
#include <zephyr/sys/printk.h>

// Adresses I2C
#define AHT20_I2C_WRITE_ADDR     0x39  // Adresse I2C pour écriture
#define AHT20_I2C_READ_ADDR      ((0x38 >> 1) | 0x08)  // Adresse I2C pour lecture

// Bits d'état
#define AHT20_STATUS_BUSY_BIT         0x80   // Bit [7] : Indication d'occupation
#define AHT20_STATUS_CALIBRATED_BIT   0x08   // Bit [3] : Indication d'étalonnage

// Commandes
#define AHT20_CONFIG_0                0x00   // Configuration du capteur à 0
#define AHT20_SOFT_RESET_BYTE         0xBA   // Effectuer un "soft reset" du capteur AHT20
#define AHT20_INIT_CMD                0xBE   // Initialisation du capteur AHT20
#define AHT20_TRIGGER_MEASUREMENT_CMD 0xAC   // Déclencher une mesure sur le capteur AHT20
#define AHT20_STATUS_BUSY_CMD         0x71   // Demande du mot d'octet de calibration

// Temps d'attente
#define WAIT_TIME_COLLECT_DATA_MS     75
#define WAIT_TIME_AFTER_POWER_ON      40
#define WAIT_TIME_AFTER_SOFT_RESET    20

// Autres
#define TEST_BUF_SIZE                 128
#define DATA_LENGTH                   6

#define I2C1_NODE DT_NODELABEL(rtc)

void main(void)
{
	printk("The I2C scanner started\n");
    const struct device *i2c_dev;
    int error;
	
    i2c_dev = device_get_binding("I2C_1");
    if (!i2c_dev) {
        printk("Binding failed.");
        return;
    }

    i2c_configure(i2c_dev, I2C_SPEED_SET(I2C_SPEED_STANDARD));
    printk("Value of NRF_TWIM2->PSEL.SCL : %d \n",NRF_TWIM1->PSEL.SCL);
    printk("Value of NRF_TWIM2->PSEL.SDA : %d \n",NRF_TWIM1->PSEL.SDA);
    printk("Value of NRF_TWIM2->FREQUENCY: %d \n",NRF_TWIM1->FREQUENCY);
    printk("26738688 -> 100k\n");

    for (uint8_t i = 4; i <= 0x7F; i++) {
        struct i2c_msg msgs[1];
        uint8_t dst = 1;

        msgs[0].buf = &dst;
        msgs[0].len = 1U;
        msgs[0].flags = I2C_MSG_WRITE | I2C_MSG_STOP;

        error = i2c_transfer(i2c_dev, &msgs[0], 1, i);
        if (error == 0) {
            printk("0x%2x FOUND\n", i);
        }
        else {
            printk("error %d \n", error);
        }
    }
	
}